import { createSignal, onMount, Show } from "solid-js";
import { Params, useParams } from "@solidjs/router";
import EmbalseType from "../interfaces/Embalse";
import Navbar from "../partials/Navbar";
import Loader from "../partials/Loader";
import Api from "../helpers/Api";
import Card from "../partials/Card";
import { FaSolidLocationDot, FaSolidLocationPin, FaSolidMapLocationDot, FaSolidWater } from "solid-icons/fa";

interface CustomParams extends Params {
  id: string;
}

function Embalse() {

  const params = useParams<CustomParams>();
  const [embalse, setEmbalse] = createSignal<EmbalseType>();

  onMount(() => {
    getEmbalse();
  });

  const getEmbalse = async () => {
    const res = await Api.embalseById(params.id);

    setEmbalse(res[0]);
  }

  return (
    <>
      <Navbar />
      <Show when={embalse() !== undefined} fallback={<Loader />}>
        <section class="hero is-fullheight">
          <div class="hero-body">
            <div class="container has-text-centered">
              <div class="columns is-centered">
                <div class="column is-half">
                  <p class="title">{embalse()!.nombre}</p>
                  <p class="subtitle">
                    <span class="icon-text">
                      <span class="icon">
                        <FaSolidMapLocationDot />
                      </span>
                      <span>{embalse()!.provincia}, {embalse()!.ccaa}</span>
                    </span>
                  </p>
                  <div class="columns is-centered is-vcentered is-multiline">
                    <div class="column is-narrow">
                      {/* Ubicación */}
                      <Card title="Ubicación" icon={<FaSolidLocationDot />}>
                        <>
                          <p><b>Latitud</b>: {embalse()!.x}</p>
                          <p><b>Longitud</b>: {embalse()!.y}</p>
                        </>
                      </Card>
                    </div>
                    <div class="column is-narrow">
                      <Card title="Caudal" icon={<FaSolidWater />}>
                        <>
                          <p><b>Actual</b>: {embalse()!.agua_actual} l/m2</p>
                          <p><b>Total</b>: {embalse()!.agua_total} l/m2</p>
                          <p><b>Porcentaje</b>: {embalse()!.agua_actual / embalse()!.agua_total * 100}%</p>
                        </>
                      </Card>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </Show>
    </>
  )
}

export default Embalse;
